/*
 * @brief LPC18xx/43xx GPIO driver
 *
 * @note
 * Copyright(C) NXP Semiconductors, 2012
 * All rights reserved.
 *
 * @par
 * Software that is described herein is for illustrative purposes only
 * which provides customers with programming information regarding the
 * LPC products.  This software is supplied "AS IS" without any warranties of
 * any kind, and NXP Semiconductors and its licensor disclaim any and
 * all warranties, express or implied, including all implied warranties of
 * merchantability, fitness for a particular purpose and non-infringement of
 * intellectual property rights.  NXP Semiconductors assumes no responsibility
 * or liability for the use of the software, conveys no license or rights under any
 * patent, copyright, mask work right, or any other intellectual property rights in
 * or to any products. NXP Semiconductors reserves the right to make changes
 * in the software without notification. NXP Semiconductors also makes no
 * representation or warranty that such application will be suitable for the
 * specified use without further testing or modification.
 *
 * @par
 * Permission to use, copy, modify, and distribute this software and its
 * documentation is hereby granted, under NXP Semiconductors' and its
 * licensor's relevant copyrights in the software, without fee, provided that it
 * is used in conjunction with NXP Semiconductors microcontrollers.  This
 * copyright, permission, and disclaimer notice must appear in all copies of
 * this code.
 */

#include "chip.h"

/*****************************************************************************
 * Private types/enumerations/variables
 ****************************************************************************/

/*****************************************************************************
 * Public types/enumerations/variables
 ****************************************************************************/

/*****************************************************************************
 * Private functions
 ****************************************************************************/

/*****************************************************************************
 * Public functions
 ****************************************************************************/

/* Initialize GPIO block */
void Chip_GPIO_Init(LPC_GPIO_T *pGPIO)
{
}

/* De-Initialize GPIO block */
void Chip_GPIO_DeInit(LPC_GPIO_T *pGPIO)
{
}

void Chip_GPIO_WriteDirBit(LPC_GPIO_T *pGPIO, uint32_t port, uint8_t bit, bool setting)
{
	if (setting) {
		pGPIO->DIR[port] |= 1UL << bit;
	}
	else {
		pGPIO->DIR[port] &= ~(1UL << bit);
	}

}

/* Set Direction for a GPIO port */
void Chip_GPIO_SetDir(LPC_GPIO_T *pGPIO, uint8_t portNum, uint32_t bitValue, uint8_t out)
{
	if (out) {
		pGPIO->DIR[portNum] |= bitValue;
	}
	else {
		pGPIO->DIR[portNum] &= ~bitValue;
	}
}

/* Enable GPIO Interrupt */
void Chip_GPIO_IntCmd(LPC_GPIOPININT_T *pGPIOPININT, uint8_t portNum, uint8_t bitValue, GPIO_INT_MODE_T mode)
{
	if (mode == GPIO_INT_RISING_EDGE) {
		pGPIOPININT->ISEL &= ~(1 << portNum);
		pGPIOPININT->IENR |= (1 << portNum);
	}
	else if (mode == GPIO_INT_FALLING_EDGE) {
		pGPIOPININT->ISEL &= ~(1 << portNum);
		pGPIOPININT->IENF |= (1 << portNum);
	}
	else if (mode == GPIO_INT_ACTIVE_HIGH_LEVEL) {
		pGPIOPININT->ISEL |= (1 << portNum);
		pGPIOPININT->IENR |= (1 << portNum);
		pGPIOPININT->SIENF |= (1 << portNum);
	}
	else {
		pGPIOPININT->ISEL |= (1 << portNum);
		pGPIOPININT->IENR |= (1 << portNum);
		pGPIOPININT->CIENF |= (1 << portNum);
	}
}

void Chip_GPIO_IntClear(LPC_GPIOPININT_T *pGPIOPININT, uint8_t portNum, uint8_t bitValue)
{
	if (!(pGPIOPININT->ISEL & (1 << portNum))) {
		pGPIOPININT->IST |= (1 << portNum);
	}

}

/* GPIO Group Interrupt Pin Add to Group */
void CHIP_GPIOGP_IntPinAdd(LPC_GPIOGROUPINT_T *pGPIOGPINT, uint8_t portNum, uint8_t PinNum, bool ActiveMode)
{
	volatile uint32_t wordDat;
	bool pinstate;

	/* configure to PORT_ENA register */
	pGPIOGPINT->PORT_ENA[portNum] |= (1 << PinNum);

	/* configure to PORT_POL */
	wordDat = pGPIOGPINT->PORT_POL[portNum];
	pinstate = (bool) (((wordDat >> PinNum) & 0x01) != 0);
	if (pinstate != ActiveMode) {
		if (ActiveMode == true) {	/* active HIGH */
			wordDat |= (1 << PinNum);
		}
		else {	/* active LOW */
			wordDat &= ~(1 << PinNum);
		}
		pGPIOGPINT->PORT_POL[portNum] = wordDat;
	}
}

